| Title: | Build Regular Expressions in a Human Readable Way |
|---|---|
| Description: | Build regular expressions piece by piece using human readable code. This package is designed for interactive use. For package development, use the rebus.* dependencies. |
| Authors: | Richard Cotton [aut, cre] |
| Maintainer: | Richard Cotton <[email protected]> |
| License: | Unlimited |
| Version: | 0.1-3 |
| Built: | 2026-06-02 09:59:46 UTC |
| Source: | https://github.com/richierocks/rebus |